.. include:: ../../README.rst

Contents:
=========

.. toctree::
   :maxdepth: 2

   usage
   contributing


Feedback
========


If you encounter any errors or problems with **dask_groupby**,
please open an issue at the GitHub http://github.com/xarray-contrib/dask_groupby main repository.
